@@ -57,7 +57,7 @@ pub struct Props {
     pub input_len: Option<usize>,              // max input len
     pub palette: HashMap<&'static str, Color>, // Use palette to store extra colors
     pub texts: TextParts,                      // text parts
-    pub value: PropValue,                      // Initial value
+    pub value: PropPayload,                    // Initial value
 }
 
 impl Default for Props {
@@ -73,28 +73,51 @@ impl Default for Props {
             input_len: None,
             palette: HashMap::new(),
             texts: TextParts::default(),
-            value: PropValue::None,
+            value: PropPayload::None,
         }
     }
 }
 
 // -- Prop value
 
-/// ### PropValue
+/// ## PropPayload
 ///
-/// PropValue describes a property initial value
-#[derive(Clone, PartialEq, std::fmt::Debug)]
-pub enum PropValue {
-    Str(String),
-    Unsigned(usize),
-    Signed(isize),
-    Float(f64),
-    Boolean(bool),
-    VecOfText(Vec<String>),
-    VecOfUsize(Vec<usize>),
+/// Payload describes a property initial value payload, which contains the actual value in different kind of storage
+#[derive(Debug, PartialEq, Clone)]
+pub enum PropPayload {
+    One(PropValue),
+    Tup2((PropValue, PropValue)),
+    Tup3((PropValue, PropValue, PropValue)),
+    Tup4((PropValue, PropValue, PropValue, PropValue)),
+    Vec(Vec<PropValue>),
+    Map(HashMap<String, PropValue>),
+    Linked(Box<PropPayload>, Option<Box<PropPayload>>),
     None,
 }
 
+/// ## PropValue
+///
+/// Value describes the value contained in a `PropPayload`
+#[derive(Debug, PartialEq, Clone)]
+pub enum PropValue {
+    Bool(bool),
+    U8(u8),
+    U16(u16),
+    U32(u32),
+    U64(u64),
+    U128(u128),
+    Usize(usize),
+    I8(i8),
+    I16(i16),
+    I32(i32),
+    I64(i64),
+    I128(i128),
+    Isize(isize),
+    F64(f64),
+    F32(f32),
+    Str(String),
+}
+
 // -- Input Type
 
 /// ## InputType
@@ -127,7 +150,45 @@ mod tests {
         assert!(props.texts.title.is_none());
         assert_eq!(props.input_type, InputType::Text);
         assert!(props.input_len.is_none());
-        assert_eq!(props.value, PropValue::None);
+        assert_eq!(props.value, PropPayload::None);
         assert!(props.texts.spans.is_none());
     }
+
+    #[test]
+    fn test_props_values() {
+        PropPayload::One(PropValue::Usize(2));
+        PropPayload::Tup2((PropValue::Bool(true), PropValue::Usize(128)));
+        PropPayload::Tup3((
+            PropValue::Bool(true),
+            PropValue::Usize(128),
+            PropValue::Str(String::from("omar")),
+        ));
+        PropPayload::Tup4((
+            PropValue::Bool(true),
+            PropValue::U8(128),
+            PropValue::Str(String::from("pippo")),
+            PropValue::Isize(-2),
+        ));
+        PropPayload::Vec(vec![
+            PropValue::U16(1),
+            PropValue::U32(2),
+            PropValue::U64(3),
+            PropValue::U128(4),
+        ]);
+        let mut map: HashMap<String, PropValue> = HashMap::new();
+        map.insert(String::from("a"), PropValue::I8(4));
+        map.insert(String::from("b"), PropValue::I16(-8));
+        map.insert(String::from("c"), PropValue::I32(16));
+        map.insert(String::from("d"), PropValue::I64(-32));
+        map.insert(String::from("e"), PropValue::I128(64));
+        PropPayload::Map(map);
+        PropPayload::Linked(Box::new(PropPayload::One(PropValue::Usize(1))), None);
+        PropPayload::Linked(
+            Box::new(PropPayload::One(PropValue::Usize(1))),
+            Some(Box::new(PropPayload::Tup2((
+                PropValue::Usize(2),
+                PropValue::Usize(4),
+            )))),
+        );
+    }
 }
